@@ -336,7 +336,6 @@ class ListField(ContainerField):
             self.items_type = self.internal_field.get_avro_type()
 
     def fake(self) -> typing.List:
-        self.generate_items_type()
         # return a list of one element with the type specified
         return [self.internal_field.fake()]
 
@@ -384,7 +383,6 @@ class DictField(ContainerField):
 
     def fake(self) -> typing.Dict[str, typing.Any]:
         # return a dict of one element with the items type specified
-        self.generate_values_type()
         return {fake.pystr(): self.internal_field.fake()}
 
 
@@ -683,8 +681,14 @@ class RecordField(BaseField):
 
         if not self.exist_type():
             user_defined_type = utils.UserDefinedType(name=name, type=self.type)
+
+            # add user_defined_type to the parent
             self.parent.user_defined_types = self.parent.user_defined_types + (user_defined_type,)
 
+            # add the parent define types to the current self.type (AvroModel) to generate valid avro schemas
+            # when inheritance has more than 2 levels
+            self.type.user_defined_types = self.type.user_defined_types + self.parent.user_defined_types
+
             record_type = self.type.avro_schema_to_python()
             record_type["name"] = name
         else:
@@ -764,6 +768,8 @@ class DecimalField(BaseField):
 
     def get_avro_type(self) -> typing.Dict[str, typing.Any]:
         avro_type = {"type": BYTES, "logicalType": DECIMAL, "precision": self.precision, "scale": self.scale}
+        if not isinstance(self.default, decimal.Decimal) and self.default.default is None:
+            return ["null", avro_type]
 
         return avro_type
 
@@ -774,6 +780,8 @@ class DecimalField(BaseField):
 
         if default == types.MissingSentinel:
             return dataclasses.MISSING
+        if default is None:
+            return None
         return serialization.decimal_to_str(default, self.precision, self.scale)
 
     def fake(self) -> decimal.Decimal:
@@ -910,6 +918,7 @@ def field_factory(
             )
 
         container_klass = CONTAINER_FIELDS_CLASSES[origin]
+        # check here
         return container_klass(  # type: ignore
             name=name,
             type=native_type,
