@@ -1,6 +1,7 @@
 import dataclasses
 import json
 import typing
+from collections import OrderedDict
 
 from dacite import Config, from_dict
 
@@ -23,7 +24,8 @@ class AvroModel:
     schema_def: typing.Optional[AvroSchemaDefinition] = None
     klass: typing.Any = None
     metadata: typing.Optional[SchemaMetadata] = None
-    user_defined_types: typing.Optional[typing.Tuple[utils.UserDefinedType]] = None
+    user_defined_types: typing.Tuple[utils.UserDefinedType] = ()
+    rendered_schema: typing.Optional[OrderedDict] = None
 
     @classmethod
     def generate_dataclass(cls: typing.Any) -> typing.Any:
@@ -43,17 +45,17 @@ class AvroModel:
             # Generate metaclass and metadata
             cls.klass = cls.generate_dataclass()
             cls.metadata = cls.generate_metadata()
-            cls.user_defined_types = ()
 
             # let's live open the possibility to define different
             # schema definitions like json
             if schema_type == "avro":
                 # cache the schema
                 cls.schema_def = cls._generate_avro_schema()
+                cls.rendered_schema = cls.schema_def.render()
             else:
                 raise ValueError("Invalid type. Expected avro schema type.")
 
-        return cls.schema_def
+        return cls.rendered_schema
 
     @classmethod
     def _generate_avro_schema(cls: typing.Any) -> AvroSchemaDefinition:
@@ -61,13 +63,13 @@ class AvroModel:
 
     @classmethod
     def avro_schema(cls: typing.Any, case_type: typing.Optional[str] = None) -> str:
-        avro_schema = cls.generate_schema(schema_type=AVRO).render()
+        avro_schema = cls.generate_schema(schema_type=AVRO)
 
         # After generating the avro schema, reset the raw_fields to the init
         cls.user_defined_types = ()
 
         if case_type is not None:
-            avro_schema = case.case_record(avro_schema, case_type)
+            avro_schema = case.case_record(cls.rendered_schema, case_type)
 
         return json.dumps(avro_schema)
 
@@ -78,7 +80,7 @@ class AvroModel:
     @classmethod
     def get_fields(cls: typing.Any) -> typing.List[FieldType]:
         if cls.schema_def is None:
-            return cls.generate_schema().fields
+            cls.generate_schema()
         return cls.schema_def.fields
 
     @staticmethod
